Index: /trunk/src/VBox/Frontends/VBoxHeadless/VBoxHeadless.h
===================================================================
--- /trunk/src/VBox/Frontends/VBoxHeadless/VBoxHeadless.h	(revision 42470)
+++ /trunk/src/VBox/Frontends/VBoxHeadless/VBoxHeadless.h	(revision 42471)
@@ -2,5 +2,5 @@
  *
  * VBox frontends: VRDE (headless Remote Desktop server):
- * Header file with registration call for VideoRec framebuffer
+ * Header file with registration call for ffmpeg framebuffer
  */
 
@@ -31,5 +31,5 @@
 
 /**
- * Callback function to register an VideoRec framebuffer.
+ * Callback function to register an ffmpeg framebuffer.
  *
  * @returns COM status code.
@@ -41,9 +41,9 @@
  * @retval  retVal       The new framebuffer
  */
-typedef DECLCALLBACK(HRESULT) FNREGISTERVIDEORECFB(ULONG width,
+typedef DECLCALLBACK(HRESULT) FNREGISTERFFMPEGFB(ULONG width,
                                      ULONG height, ULONG bitrate,
                                      com::Bstr filename,
                                      IFramebuffer **retVal);
-typedef FNREGISTERVIDEORECFB *PFNREGISTERVIDEORECFB;
+typedef FNREGISTERFFMPEGFB *PFNREGISTERFFMPEGFB;
 
 #endif // __H_VBOXHEADLESS
Index: /trunk/src/VBox/Frontends/VBoxHeadless/VideoCapture/Makefile.kmk
===================================================================
--- /trunk/src/VBox/Frontends/VBoxHeadless/VideoCapture/Makefile.kmk	(revision 42470)
+++ /trunk/src/VBox/Frontends/VBoxHeadless/VideoCapture/Makefile.kmk	(revision 42471)
@@ -19,29 +19,28 @@
 include $(KBUILD_PATH)/subheader.kmk
 
-DLLS += VBoxVideoRecFB
-VBoxVideoRecFB_TEMPLATE     = VBOXMAINCLIENTDLL
+DLLS += VBoxFFmpegFB
+VBoxFFmpegFB_TEMPLATE     = VBOXMAINCLIENTDLL
 
 ifdef VBOX_WITH_VPX
-  VBoxVideoRecFB_DEFS      += \
+  VBoxFFmpegFB_DEFS      += \
     VBOX_WITH_VPX  
 endif
 
 ifdef VBOX_WITH_VPX
-  VBoxVideoRecFB_SDKS       = VBOX_FFMPEG VBOX_LIBPNG VBOX_ZLIB VBOX_VPX
+  VBoxFFmpegFB_SDKS       = VBOX_FFMPEG VBOX_LIBPNG VBOX_ZLIB VBOX_VPX
 else
-  VBoxVideoRecFB_SDKS       = VBOX_FFMPEG VBOX_LIBPNG VBOX_ZLIB 
+  VBoxFFmpegFB_SDKS       = VBOX_FFMPEG VBOX_LIBPNG VBOX_ZLIB 
 endif
 
 ifdef VBOX_WITH_VPX
-  VBoxVideoRecFB_SOURCES   +=  \
-    VideoRecFB.cpp \
-    EbmlWriter.cpp \
-    EncodeAndWrite.cpp
+  VBoxFFmpegFB_SOURCES   +=  \
+    FFmpegFB.cpp \
+	EbmlWriter.cpp
 else
-  VBoxVideoRecFB_SOURCES   +=  \
-    VideoRecFB.cpp 
+  VBoxFFmpegFB_SOURCES   +=  \
+    FFmpegFB.cpp 
 endif
 
-VBoxVideoRecFB_CXXFLAGS.linux += -fPIC
+VBoxFFmpegFB_CXXFLAGS.linux += -fPIC
 
 include $(FILE_KBUILD_SUB_FOOTER)

Index: /trunk/src/VBox/Frontends/VBoxHeadless/VBoxHeadless.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VBoxHeadless/VBoxHeadless.cpp	(revision 42470)
+++ /trunk/src/VBox/Frontends/VBoxHeadless/VBoxHeadless.cpp	(revision 42471)
@@ -471,6 +471,6 @@
              "                                         \"TCP/Address\" - interface IP the VRDE server\n"
              "                                         will bind to\n"
-             "   --settingspw                          Specify the settings password\n"
-             "   --settingspwfile                      Specify a file containing the settings password\n"
+             "   --settingspw <pw>                     Specify the settings password\n"
+             "   --settingspwfile <file>               Specify a file containing the settings password\n"
 #ifdef VBOX_WITH_VIDEO_REC
              "   -c, -capture, --capture               Record the VM screen output to a file\n"
@@ -486,5 +486,5 @@
 #ifdef VBOX_WITH_VIDEO_REC
 /**
  * Parse the environment for variables which can influence the VIDEOREC settings.
  * purely for backwards compatibility.
  * @param pulFrameWidth may be updated with a desired frame width
@@ -613,5 +613,5 @@
     unsigned fCSAM  = ~0U;
 #ifdef VBOX_WITH_VIDEO_REC
-    unsigned fVIDEOREC = 0;
+    unsigned fFFMPEG = 0;
     unsigned long ulFrameWidth = 800;
     unsigned long ulFrameHeight = 600;
@@ -755,5 +755,5 @@
 #ifdef VBOX_WITH_VIDEO_REC
             case 'c':
-                fVIDEOREC = true;
+                fFFMPEG = true;
                 break;
             case 'w':
@@ -931,8 +931,8 @@
 #ifdef VBOX_WITH_VIDEO_REC
         IFramebuffer *pFramebuffer = 0;
-        RTLDRMOD hLdrVideoRecFB;
-        PFNREGISTERVIDEORECFB pfnRegisterVideoRecFB;
-
-        if (fVIDEOREC)
+        RTLDRMOD hLdrFFmpegFB;
+        PFNREGISTERFFMPEGFB pfnRegisterFFmpegFB;
+
+        if (fFFMPEG)
         {
             HRESULT         rcc = S_OK;
@@ -940,13 +940,13 @@
             RTERRINFOSTATIC ErrInfo;
 
-            Log2(("VBoxHeadless: loading VBoxVideoRecFB and libvpx shared library\n"));
+            Log2(("VBoxHeadless: loading VBoxFFmpegFB and libvpx shared library\n"));
             RTErrInfoInitStatic(&ErrInfo);
-            rrc = SUPR3HardenedLdrLoadAppPriv("VBoxVideoRecFB", &hLdrVideoRecFB, RTLDRLOAD_FLAGS_LOCAL, &ErrInfo.Core);
+            rrc = SUPR3HardenedLdrLoadAppPriv("VBoxFFmpegFB", &hLdrFFmpegFB, RTLDRLOAD_FLAGS_LOCAL, &ErrInfo.Core);
 
             if (RT_SUCCESS(rrc))
             {
-                Log2(("VBoxHeadless: looking up symbol VBoxRegisterVideoRecFB\n"));
-                rrc = RTLdrGetSymbol(hLdrVideoRecFB, "VBoxRegisterVideoRecFB",
-                                     reinterpret_cast<void **>(&pfnRegisterVideoRecFB));
+                Log2(("VBoxHeadless: looking up symbol VBoxRegisterFFmpegFB\n"));
+                rrc = RTLdrGetSymbol(hLdrFFmpegFB, "VBoxRegisterFFmpegFB",
+                                     reinterpret_cast<void **>(&pfnRegisterFFmpegFB));
                 if (RT_FAILURE(rrc))
                     LogError("Failed to load the video capture extension, possibly due to a damaged file\n", rrc);
@@ -956,6 +956,6 @@
             if (RT_SUCCESS(rrc))
             {
-                Log2(("VBoxHeadless: calling pfnRegisterVideoRecFB\n"));
-                rcc = pfnRegisterVideoRecFB(ulFrameWidth, ulFrameHeight, ulBitRate,
+                Log2(("VBoxHeadless: calling pfnRegisterFFmpegFB\n"));
+                rcc = pfnRegisterFFmpegFB(ulFrameWidth, ulFrameHeight, ulBitRate,
                                          pszMPEGFile, &pFramebuffer);
                 if (rcc != S_OK)
@@ -984,5 +984,5 @@
         {
 # ifdef VBOX_WITH_VIDEO_REC
-            if (fVIDEOREC && uScreenId == 0)
+            if (fFFMPEG && uScreenId == 0)
             {
                 /* Already registered. */
@@ -486,5 +486,5 @@
 #ifdef VBOX_WITH_VIDEO_REC
 /**
- * Parse the environment for variables which can influence the VIDEOREC settings.
+ * Parse the environment for variables which can influence the FFMPEG settings.
  * purely for backwards compatibility.
  * @param pulFrameWidth may be updated with a desired frame width